import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
import requests

'''
announce_type = all
业绩预告
announce_type ='eq-f1001'
重大事项
announce_type ='eq-f1002'
股份变动公告
announce_type ='eq-f1003'

'''


# 公司公告数据
def get_company_announce_info(symbol, market_id, announce_type, page_size, page_number):
    headers = {
        "Accept": "*/*",
        "Accept-Language": "zh-CN,zh;q=0.9",
        "Connection": "keep-alive",
        "Referer": "https://basic.10jqka.com.cn/new/" + str(symbol) + "/news.html",
        "Sec-Fetch-Dest": "empty",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-origin",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/129.0.0.0 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
        "hexin-v": "A26_5Ky-hXryQvEeROXOP_Umv881bzAERDPmR5g32nEsewBxAP-CeRTDNldr",
        "sec-ch-ua": "\"Google Chrome\";v=\"129\", \"Not=A?Brand\";v=\"8\", \"Chromium\";v=\"129\"",
        "sec-ch-ua-mobile": "?0",
        "sec-ch-ua-platform": "\"Windows\""
    }
    cookies = {
        "searchGuide": "sg",
        "Hm_lvt_78c58f01938e4d85eaf619eae71b4ed1": "1729691262",
        "skin_color": "white",
        "historystock": "870357%7C*%7C833781%7C*%7C873576%7C*%7C835892%7C*%7C873693",
        "reviewJump": "nojump",
        "usersurvey": "1",
        "v": "A26_5Ky-hXryQvEeROXOP_Umv881bzAERDPmR5g32nEsewBxAP-CeRTDNldr"
    }
    url = "https://basic.10jqka.com.cn/basicapi/notice/pub"
    params = {
        "type": "stock",
        "limit": str(page_size),
        "page": str(page_number),
        "code": str(symbol),
        "classify": announce_type,
        "market": str(market_id)
    }
    response = requests.get(url, headers=headers, cookies=cookies, params=params)
    data_json = response.json()
    temp_df = pd.DataFrame(data_json["data"]["data"])
    return temp_df


if __name__ == '__main__':
    get_company_announce_info('300085', '33', 'eq-f1003', 100, 1)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

from xtquant import xtdata
import time


def my_download(stock_list: list, period: str, start_date='', end_date=''):
    '''
    用于显示下载进度
    '''
    import string

    if [i for i in ["d", "w", "mon", "q", "y", ] if i in period]:
        period = "1d"
    elif "m" in period:
        numb = period.translate(str.maketrans("", "", string.ascii_letters))
        if int(numb) < 5:
            period = "1m"
        else:
            period = "5m"
    elif "tick" == period:
        pass
    else:
        raise KeyboardInterrupt("周期传入错误")

    n = 1
    num = len(stock_list)
    for i in stock_list:
        print(f"当前正在下载 {period} {n}/{num}")

        xtdata.download_history_data(i, period, start_date, end_date)
        n += 1
    print("下载任务结束")


def do_subscribe_quote(stock_list: list, period: str):
    for i in stock_list:
        xtdata.subscribe_quote(i, period=period)
    time.sleep(1)  # 等待订阅完成


if __name__ == "__main__":

    start_date = '20220101'  # 格式"YYYYMMDD"，开始下载的日期，date = ""时全量下载
    end_date = ""
    period = "1m"

    need_download = 1  # 取数据是空值时，将need_download赋值为1，确保正确下载了历史数据

    code_list = ["588000.SH", "600519.SH"]  # 股票列表

    if need_download:  # 判断要不要下载数据, gmd系列函数都是从本地读取历史数据,从服务器订阅获取最新数据
        my_download(code_list, period, start_date, end_date)

    ############ 仅获取历史行情 #####################
    count = -1  # 设置count参数，使gmd_ex返回全部数据
    data1 = xtdata.get_market_data_ex([], code_list, period=period, start_time=start_date, end_time=end_date)

    ############ 仅获取最新行情 #####################
    do_subscribe_quote(code_list, period)  # 设置订阅参数，使gmd_ex取到最新行情
    count = 1  # 设置count参数，使gmd_ex仅返回最新行情数据
    data2 = xtdata.get_market_data_ex([], code_list, period=period, start_time=start_date, end_time=end_date,
                                      count=1)  # count 设置为1，使返回值只包含最新行情

    ############ 获取历史行情+最新行情 #####################
    do_subscribe_quote(code_list, period)  # 设置订阅参数，使gmd_ex取到最新行情
    count = -1  # 设置count参数，使gmd_ex返回全部数据
    data3 = xtdata.get_market_data_ex([], code_list, period=period, start_time=start_date, end_time=end_date,
                                      count=-1)  # count 设置为1，使返回值只包含最新行情

    print(data1[code_list[0]].tail())  # 行情数据查看
    print(data2[code_list[0]].tail())
    print(data3[code_list[0]].tail())






import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import requests


def get_qq_hang_qing():
    url = 'https://proxy.finance.qq.com/cgi/cgi-bin/rank/hs/getBoardRankList?_appver=11.17.0&board_code=aStock&sort_type=turnover&direct=down&offset=1&count=1'
    return requests.get(url)


if __name__ == '__main__':
    while True:
        r = get_qq_hang_qing()
        print(r.status_code)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
from functools import lru_cache
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import pandas as pd

mongodb_util = MongodbUtil('27017')


@lru_cache(maxsize=None)
def get_company_info_by_field(query_key, query_field_key):
    query = eval(query_key)
    query_field = eval(query_field_key)
    return mongodb_util.find_query_data_choose_field('company_info', query, query_field)


# 获取退市股票代码
@lru_cache(maxsize=None)
def get_de_list_company():
    return list(mongodb_util.find_all_data(db_name_constant.DE_LIST_STOCK)['symbol'])


# 获取公司详情
@lru_cache(maxsize=None)
def get_company_info_info():
    return mongodb_util.find_query_data_choose_field('company_info', {},
                                                     {"_id": 1,
                                                      "industry": 1,
                                                      "company_type": 1,
                                                      "ths_concept_name": 1,
                                                      "ths_concept_code": 1,
                                                      "ths_concept_sync_day": 1,
                                                      'sub_stock': 1,
                                                      "first_sw_industry": 1,
                                                      "second_sw_industry": 1,
                                                      "third_sw_industry": 1,
                                                      "mv_circulation_ratio": 1,
                                                      "diff_days": 1,
                                                      "list_date": 1,
                                                      'em_industry': 1,
                                                      'ths_concept_list_info': 1,
                                                      'ths_concept_name_list_str': 1,
                                                      "kpl_plate_name": 1,
                                                      "kpl_plate_list_info": 1,
                                                      'operate_profit': 1,
                                                      'total_operate_income': 1,
                                                      "flow_mv_sp": 1,
                                                      "total_mv_sp": 1
                                                      })


def clear_company_info_cache():
    get_company_info_info.cache_clear()


# 使用同花顺行业分类
def amend_ths_industry(real_time_quotes_now_init):
    real_time_quotes_now = real_time_quotes_now_init.copy()
    query_field = {"_id": 1, "industry": 1, "company_type": 1,
                   "ths_concept_name": 1, "ths_concept_code": 1,
                   "ths_concept_sync_day": 1, 'sub_stock': 1,
                   "first_sw_industry": 1, "second_sw_industry": 1,
                   "third_sw_industry": 1, "mv_circulation_ratio": 1,
                   "list_date": 1, 'ths_concept_list_info': 1, 'ths_concept_name_list_str': 1,
                   "ths_concept_list": 1,
                   "diff_days": 1, 'em_industry': 1,
                   "kpl_plate_name": 1, "kpl_plate_list_info": 1,
                   'operate_profit': 1,
                   'total_operate_income': 1,
                   "name": 1,
                   'pb': 1, 'pe_ttm': 1, 'ROE': 1
                   }
    query_field_key = str(query_field)
    query = {}
    query_key = str(query)

    industry_group_df = get_company_info_by_field(query_key, query_field_key)
    if 'list_date' in real_time_quotes_now.columns:
        del real_time_quotes_now['list_date']
    if 'name' in real_time_quotes_now.columns:
        del real_time_quotes_now['name']
    if 'industry' in real_time_quotes_now.columns:
        del real_time_quotes_now['industry']

    industry_group_df = industry_group_df.set_index(['_id'], drop=True)
    real_time_quotes_now = real_time_quotes_now.set_index(['symbol'], drop=False)
    real_time_quotes_now = pd.merge(real_time_quotes_now, industry_group_df, how='outer',
                                    left_index=True, right_index=True)
    real_time_quotes_now.dropna(subset=['symbol'], axis=0, inplace=True)

    symbol_list = list(real_time_quotes_now['symbol'])

    na_industry_data = real_time_quotes_now_init.loc[
        ~(real_time_quotes_now_init['symbol'].isin(symbol_list))]
    # 修复空值
    na_industry_data = na_industry_data.loc[na_industry_data['amount'] != 0]

    real_time_quotes_now_result = pd.concat([real_time_quotes_now, na_industry_data], axis=0)
    real_time_quotes_now.fillna({'connected_boards_numbers': 1}, inplace=True)

    # 处理na值
    real_time_quotes_now_result.fillna(0, inplace=True)
    return real_time_quotes_now_result


# 获取公司详情
@lru_cache(maxsize=None)
def get_company_all_info_info():
    return mongodb_util.find_query_data_choose_field('company_info', {},
                                                     {"ths_concept_list_info": 0,
                                                      "kpl_plate_list_info": 0,
                                                      })


def clear_company_all_info_cache():
    get_company_all_info_info.cache_clear()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.api.proxies.liu_guan_proxy_api as liu_guan_proxy_api
import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import datetime
import requests
import time
from loguru import logger
from functools import lru_cache
import mns_common.api.em.real_time.east_money_stock_a_api as east_money_stock_a_api
import threading

mongodb_util = MongodbUtil('27017')


def query_liu_guan_proxy_ip():
    ip_proxy_pool = mongodb_util.find_all_data(db_name_constant.IP_PROXY_POOL)
    return ip_proxy_pool


def remove_proxy_ip():
    mongodb_util.remove_data({}, db_name_constant.IP_PROXY_POOL)


def check_valid(ip_proxy_pool):
    effect_time = list(ip_proxy_pool['effect_time'])[0]

    now_date = datetime.datetime.now()

    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')

    if effect_time > str_now_date:
        return True
    else:
        remove_proxy_ip()
        return False


@lru_cache(maxsize=None)
def get_account_cache():
    query = {"type": "liu_guan_proxy", }
    return mongodb_util.find_query_data(db_name_constant.STOCK_ACCOUNT_INFO, query)


def generate_proxy_ip_api(minutes):
    stock_account_info = get_account_cache()
    order_id = list(stock_account_info['password'])[0]
    secret = list(stock_account_info['account'])[0]
    # 获取10分钟动态ip
    ip = liu_guan_proxy_api.get_proxy_api(order_id, secret, str(60 * minutes))
    return ip


def generate_proxy_ip(minutes):
    ip_proxy_pool = mongodb_util.find_all_data(db_name_constant.IP_PROXY_POOL)
    if data_frame_util.is_not_empty(ip_proxy_pool):
        return list(ip_proxy_pool['ip'])[0]
    else:
        remove_proxy_ip()
        now_date = datetime.datetime.now()
        # 加上分钟
        time_to_add = datetime.timedelta(minutes=minutes)
        new_date = now_date + time_to_add
        str_now_date = new_date.strftime('%Y-%m-%d %H:%M:%S')
        # 获取10分钟动态ip
        while True:
            remove_proxy_ip()
            ip = generate_proxy_ip_api(minutes)
            if check_proxy(ip):
                result_dict = {"_id": ip,
                               'effect_time': str_now_date,
                               'ip': ip}
                result_df = pd.DataFrame(result_dict, index=[1])

                mongodb_util.insert_mongo(result_df, db_name_constant.IP_PROXY_POOL)
                break
            else:
                time.sleep(0.5)
        return ip


def get_proxy_ip(minutes):
    ip_proxy_pool = query_liu_guan_proxy_ip()
    if data_frame_util.is_empty(ip_proxy_pool):
        return generate_proxy_ip(minutes)
    else:
        if check_valid(ip_proxy_pool):
            return list(ip_proxy_pool['ip'])[0]
        else:
            return generate_proxy_ip(minutes)


def check_proxy(proxy_ip):
    try:
        # 两秒超时
        test_df = call_with_timeout(get_em_real_time_data, proxy_ip, timeout=2)
        if data_frame_util.is_not_empty(test_df):
            logger.info("可用代理ip:{}", proxy_ip)
            return True
        else:
            return False
    except Exception as e:
        logger.error("代理ip不可用:{},{}", proxy_ip, e)
        return False


def get_em_real_time_data(proxy_ip):
    proxies = {
        "http": proxy_ip,
        "https": proxy_ip
    }
    return east_money_stock_a_api.get_stock_page_data(1, proxies, 20)


# 定义一个带超时的函数调用
def call_with_timeout(func, *args, timeout=2, **kwargs):
    # 用于存储函数执行结果
    result = None
    exception = None

    # 定义一个线程目标函数
    def target():
        nonlocal result, exception
        try:
            result = func(*args, **kwargs)
        except Exception as e:
            exception = e

    # 创建线程并启动
    thread = threading.Thread(target=target)
    thread.start()

    # 等待线程完成，最多等待 timeout 秒
    thread.join(timeout)

    # 如果线程仍然存活，说明函数超时了
    if thread.is_alive():
        raise TimeoutError(f"Function exceeded timeout of {timeout} seconds")

    # 如果函数抛出了异常，重新抛出
    if exception is not None:
        raise exception
    return result


if __name__ == "__main__":
    generate_proxy_ip(1)



import threading
from functools import wraps
from typing import Optional, Callable

class ExceptionMonitor:
    """支持动态配置的异常监控器"""
    def __init__(
        self,
        threshold: int = 1000,
        alert_handler: Optional[Callable[[int, int], None]] = None,
        auto_reset: bool = True
    ):
        """
        :param threshold: 报警阈值，默认1000次
        :param alert_handler: 自定义报警函数，格式 func(current_count, threshold)
        :param auto_reset: 触发报警后是否自动重置计数器
        """
        self.counter = 0
        self._threshold = threshold
        self.alert_handler = alert_handler
        self.auto_reset = auto_reset
        self.lock = threading.Lock()

    @property
    def threshold(self) -> int:
        """当前报警阈值"""
        return self._threshold

    @threshold.setter
    def threshold(self, value: int):
        """动态设置报警阈值"""
        with self.lock:
            self._threshold = value

    def increment(self):
        """线程安全的计数器递增"""
        with self.lock:
            self.counter += 1
            if self.counter >= self.threshold:
                self.trigger_alert()
                if self.auto_reset:
                    self.reset_counter()

    def reset_counter(self):
        """手动重置计数器"""
        with self.lock:
            self.counter = 0

    def trigger_alert(self):
        """触发报警（支持自定义处理逻辑）"""
        if self.alert_handler:
            self.alert_handler(self.counter, self.threshold)
        else:
            print(f"[ALERT] Exception count {self.counter} exceeded threshold {self.threshold}")

def exception_counter(
    threshold: int = 1000,
    alert_handler: Optional[Callable[[int, int], None]] = None,
    auto_reset: bool = True
):
    """
    异常计数装饰器工厂
    :param threshold: 报警阈值
    :param alert_handler: 自定义报警处理函数
    :param auto_reset: 是否自动重置计数器
    """
    def decorator(func):
        # 为每个被装饰函数创建独立监控实例
        monitor = ExceptionMonitor(
            threshold=threshold,
            alert_handler=alert_handler,
            auto_reset=auto_reset
        )

        @wraps(func)
        def wrapper(*args, **kwargs):
            try:
                return func(*args, **kwargs)
            except Exception as e:
                monitor.increment()
                raise  # 保持原始异常栈

        # 暴露监控器以便外部访问
        wrapper.monitor = monitor
        return wrapper
    return decorator


import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

# 同花顺 美股地址:https://basic.10jqka.com.cn/168/PINS/company.html



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import requests
import pandas as pd


# year 年
#  quarter 季度
# month 月度
# week 周
# day 日
def get_xue_qiu_k_line(symbol, period, cookie, end_time, hq):
    url = "https://stock.xueqiu.com/v5/stock/chart/kline.json"

    params = {
        "symbol": symbol,
        "begin": end_time,
        "period": period,
        "type": hq,
        "count": "-120084",
        "indicator": "kline,pe,pb,ps,pcf,market_capital,agt,ggt,balance"
    }

    headers = {
        "accept": "application/json, text/plain, */*",
        "accept-language": "zh-CN,zh;q=0.9",
        "origin": "https://xueqiu.com",
        "priority": "u=1, i",
        "referer": "https://xueqiu.com/S/SZ300879?md5__1038=n4%2BxgDniDQeWqxYwq0y%2BbDyG%2BYDtODuD7q%2BqRYID",
        "sec-ch-ua": '"Chromium";v="134", "Not:A-Brand";v="24", "Google Chrome";v="134"',
        "sec-ch-ua-mobile": "?0",
        "sec-ch-ua-platform": '"Windows"',
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/134.0.0.0 Safari/537.36",
        "cookie": cookie
    }

    response = requests.get(
        url=url,
        params=params,
        headers=headers
    )

    if response.status_code == 200:
        response_data = response.json()
        df = pd.DataFrame(
            data=response_data['data']['item'],
            columns=response_data['data']['column']
        )







        # 1. 转换为 datetime（自动处理毫秒级时间戳）
        df["beijing_time"] = pd.to_datetime(df["timestamp"], unit="ms")

        # 2. 设置 UTC 时区
        df["beijing_time"] = df["beijing_time"].dt.tz_localize("UTC")

        # 3. 转换为北京时间（UTC+8）
        df["beijing_time"] = df["beijing_time"].dt.tz_convert("Asia/Shanghai")

        # 4. 提取年月日（格式：YYYY-MM-DD）
        df["str_day"] = df["beijing_time"].dt.strftime("%Y-%m-%d")
        del df["beijing_time"]

        return df
    else:
        # 直接抛出带有明确信息的异常
        raise ValueError("调用雪球接口失败")


if __name__ == '__main__':
    number = 1
    cookies = 'cookiesu=431747207996803; device_id=e7bd664c2ad4091241066c3a2ddbd736; xq_is_login=1; u=9627701445; s=ck12tdw0na; bid=7a2d53b7ab3873ab7ec53349413f0a21_mb9aqxtx; xq_a_token=9367502e9138a95092fac9fb24c5348edb095013; xqat=9367502e9138a95092fac9fb24c5348edb095013; xq_id_token=eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9.eyJ1aWQiOjk2Mjc3MDE0NDUsImlzcyI6InVjIiwiZXhwIjoxNzUyMDM2NTM4LCJjdG0iOjE3NDk0NDQ1MzgzMDgsImNpZCI6ImQ5ZDBuNEFadXAifQ.rKuCHOgTHaMp0wRkvkPjNz8YrV6oia1xVAY35MmlYPlTvIYDEqsxqI3Qyz2dh5UuBC4TSlJUmVOEbvZzrM990-RaqT1rYCPjHaAZo4qDsOz34ypEAXJBzYaz32KPTGbM9lDwOFuHxeSUFeM0R-2Lhe3UbmRPU_zEBneuCQ_vrz4DkM98qswZ9emA3B8mty-Qa-40NrCb0xLZ52Oi8VKwEJXoPmlsEE3D2vxB0v0qEaKDjBSanCpe0mHCE4ds1yHaZvfV2zSRl1PYcCF85yiCtba3jYkQJ4lR2hmk9AyYOAtnQ-1aiYGjgNpe9ETJGvnoG_o3WUJmFFl0nAENqvviNQ; xq_r_token=59ae4e9f9cc1ed66343ff1e68a7b32c0d8c27983; Hm_lvt_1db88642e346389874251b5a1eded6e3=1749548204,1749603966,1749606594,1749630748; HMACCOUNT=16733F9B51C8BBB0; is_overseas=0; Hm_lpvt_1db88642e346389874251b5a1eded6e3=1749630957; ssxmod_itna=QqjOAKYIwGkYDQG0bGCYG2DmxewDAo40QDXDUqAQtGgnDFqAPDODCOG/iwQEgM8DbPKitDD5bh9xGXPmDA5DnGx7YDtr49v+i9gGB+eQpcAb4bRGApg4OQXWWOYB0hOEBDpAav72v1mDB3DbqDyKiIuB4GGf4GwDGoD34DiDDpfD03Db4D+nWrD7ORQMluokePDQ4GyDitQigWDA4DjIQx+G7bOPnbYDDNYeK+eIfYODYpogW0FrxqDAkDtgkbDjkPD/SGjcPDBnIkYepuEgqOp8CcaxBQD7dF=oeq8jmWNaegu/YNVBbIwCDIQGeWm3lxYWDVQG3WxOmDKID5CI3WmeYqqnDOGYu0PNb4DDPoWDbYxH/GeohS85lImlA5ot+Q0qDLizW+KaRxKoU8G08DUY2D9rN/riYGxtiqKOqxhKND+/HPeD; ssxmod_itna2=QqjOAKYIwGkYDQG0bGCYG2DmxewDAo40QDXDUqAQtGgnDFqAPDODCOG/iwQEgM8DbPKitDD5bhYxD3betID4WDLDlGWvDBq9DE0336bqjR87=Rad7dn=250R0FgdQyhaMthWK7TYTInPnkD/bGDDkB3YUTfXD4dyGD0AKw=fKlNSjmXgKBLeBgr9+CGx1qKqopRQHDtQ1daQVMwqWPa2+Z32+QuOaZc3WZXW=Pa821DB9ZXe30HfGwBv28yHVY7EmEY8yPcmMfMEMR6in3XQkYh0uCDLybC=hOxU/YkDdfxP1NRN3bLXK61i4z6hz1rKi7sBTQZ2Wjw33+O78=tSTK8dwbrKh==4+7RidD+4exl2+4Mb+Q1TobeGFsr7iGembt2QblAYrbKqDrRjsqYN9evSeQFk3tErsGdtAOsS3PgACx1mGe0mf2C5ZB5xhDKBD=7fsaKsP44D'
    while True:
        test_df = get_xue_qiu_k_line('SZ000001', 'day', cookies, '1749744000000', 'after')
        print(number)
        number = number + 1
